@@ -62,20 +62,30 @@ trim() {
     echo -n "$var"
 }
 
-vivado $viv_args 2>&1 | while IFS= read -r line
+VIVADO_COMMAND="vivado"
+if command -v vivado_lab >/dev/null 2>&1; then
+    VIVADO_COMMAND=vivado_lab
+fi
+
+$VIVADO_COMMAND $viv_args 2>&1 | while IFS= read -r line
+
 do
-    case $(trim $line) in
-        ERROR:*)
-            eval $ERR_CLR; echo "$line"; eval $CLR_OFF
-            ;;
-        CRITICAL[[:space:]]WARNING:*)
-            eval $CRIWARN_CLR; echo "$line"; eval $CLR_OFF
-            ;;
-        WARNING:*)
-            eval $WARN_CLR; echo "$line"; eval $CLR_OFF
-            ;;
-        *)
-            echo "$line"
-    esac
+    if [[ $line != \#* ]]; then # Ignore script output
+        case $(trim $line) in
+            *ERROR:*|*Error:*)
+                eval $ERR_CLR; echo "$line"; eval $CLR_OFF
+                ;;
+            *CRITICAL[[:space:]]WARNING:*|*Crtical[[:space:]]Warning:*)
+                eval $CRIWARN_CLR; echo "$line"; eval $CLR_OFF
+                ;;
+            *WARNING:*|*Warning:*)
+                eval $WARN_CLR; echo "$line"; eval $CLR_OFF
+                ;;
+            *)
+                echo "$line"
+        esac
+    else
+        echo "$line"
+    fi
 done
 exit ${PIPESTATUS[0]}
