@@ -46,6 +46,8 @@ proc ::vivado_utils::initialize_project { {save_to_disk 0} } {
     variable g_output_dir
     variable g_source_files
 
+    variable bd_files ""
+
     file delete -force $g_output_dir/build.rpt
 
     if {$save_to_disk == 1} {
@@ -73,6 +75,12 @@ proc ::vivado_utils::initialize_project { {save_to_disk 0} } {
         } elseif [expr [lsearch {.ngc .edif} $src_ext] >= 0] {
             puts "BUILDER: Adding Netlist : $src_file"
             read_edif $src_file
+        } elseif [expr [lsearch {.bd} $src_ext] >= 0] {
+            puts "BUILDER: Adding Block Design to list (added after IP regeneration): $src_file"
+            append bd_files "$src_file "
+        } elseif [expr [lsearch {.bxml} $src_ext] >= 0] {
+            puts "BUILDER: Adding Block Design XML to list (added after IP regeneration): $src_file"
+            append bd_files "$src_file "
         } else {
             puts "BUILDER: \[WARNING\] File ignored!!!: $src_file"
         }
@@ -82,6 +90,12 @@ proc ::vivado_utils::initialize_project { {save_to_disk 0} } {
     generate_target all [get_ips *]
     synth_ip [get_ips *]
 
+    #might seem silly, but we need to add the bd files after the ip regeneration.
+    foreach file $bd_files {
+        puts "BUILDER: Adding file from Block Design list: $file"
+        add_files -norecurse $file
+    } 
+
     puts "BUILDER: Setting $g_top_module as the top module"
     set_property top $g_top_module [current_fileset]
 }
@@ -122,6 +136,7 @@ proc ::vivado_utils::generate_post_synth_reports {} {
     write_checkpoint -force $g_output_dir/post_synth
     puts "BUILDER: Writing post-synthesis reports"
     report_utilization -file $g_output_dir/post_synth_util.rpt
+    report_utilization -hierarchical -file $g_output_dir/post_synth_util_hier.rpt
     report_drc -ruledeck methodology_checks -file $g_output_dir/methodology.rpt
     report_high_fanout_nets -file $g_output_dir/high_fanout_nets.rpt
 }
@@ -137,6 +152,7 @@ proc ::vivado_utils::generate_post_place_reports {} {
     puts "BUILDER: Writing post-placement reports"
     report_clock_utilization -file $g_output_dir/clock_util.rpt
     report_utilization -file $g_output_dir/post_place_util.rpt
+    report_utilization -hierarchical -file $g_output_dir/post_place_util_hier.rpt
     report_timing -sort_by group -max_paths 5 -path_type summary -file $g_output_dir/post_place_timing.rpt
 }
 
@@ -154,6 +170,7 @@ proc ::vivado_utils::generate_post_route_reports {} {
     }
     report_timing_summary -file $g_output_dir/post_route_timing_summary.rpt
     report_utilization -file $g_output_dir/post_route_util.rpt
+    report_utilization -hierarchical -file $g_output_dir/post_route_util_hier.rpt
     report_power -file $g_output_dir/post_route_power.rpt
     report_drc -file $g_output_dir/post_imp_drc.rpt
     report_timing -sort_by group -max_paths 10 -path_type summary -file $g_output_dir/post_route_timing.rpt
