@@ -9,7 +9,7 @@ source $::env(VIV_TOOLS_DIR)/scripts/viv_strategies.tcl
 vivado_utils::initialize_project
 
 # STEP#2: Run synthesis 
-vivado_utils::synthesize_design
+vivado_utils::synthesize_design -directive AreaOptimized_high -control_set_opt_threshold 1
 vivado_utils::generate_post_synth_reports
 
 # STEP#3: Run implementation strategy
